@@ -4,7 +4,11 @@ fn main() {
         return;
     }
 
-    if let Some(code) = fbt_lib::main() {
+    let mut args = std::env::args();
+    args.next(); // get rid of first element (name of binary)
+    let args: Vec<_> = args.filter(|v| !v.starts_with('-')).collect();
+
+    if let Some(code) = fbt_lib::main_with_filters(&args) {
         std::process::exit(code)
     }
 }
